.. meta::
   :description: Gaitalytics References.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, references

Reference
=========

.. toctree::
    :glob:

    *
